# paths

## Bash Executable
```
--detect.bash.path
```

Path to the Bash executable\.

If set, Detect will use the given Bash executable instead of searching for one\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|`/usr/bin/bash`|

## BDIO Output Directory
```
--detect.bdio.output.path
```

The path to the output directory for all BDIO files\.

If not set, the BDIO files are placed in a 'BDIO' subdirectory of the output directory\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## BDIO File Name
```
--detect.bdio.file.name
```

The desired file name of the single bdio file Detect produces in the BDIO Output Directory\.

If not set, the file name is generated from your project, version and code location names\.

|Details||
|---|---|
|Added|7\.9\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Detector Search Depth
```
--detect.detector.search.depth=0
```

Depth of subdirectories within the source directory to which Detect will search for files that indicate whether a detector applies\.

A value of 0 \(the default\) tells Detect not to search any subdirectories, a value of 1 tells Detect to search first\-level subdirectories, etc\.

|Details||
|---|---|
|Added|3\.2\.0|
|Type|Integer|
|Default Value|0|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Git Executable
```
--detect.git.path
```

Path of the git executable



|Details||
|---|---|
|Added|5\.5\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Java Executable
```
--detect.java.path
```

Path to the java executable\.

If set, Detect will use the given java executable instead of searching for one\.

|Details||
|---|---|
|Added|5\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Detect Output Path
```
--detect.output.path
```

The path to the output directory\.

If set, Detect will use the given directory to store files that it downloads and creates, instead of using the default location \(~/blackduck\)\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Swift Executable
```
--detect.swift.path
```

Path of the swift executable\.



|Details||
|---|---|
|Added|6\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Sbt Executable
```
--detect.sbt.path
```

Path to the Sbt executable\.

If set, Detect will use the given Sbt executable instead of searching for one\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|`C:\Program Files (x86)\sbt\bin\sbt.bat`|

## Scan Output Path
```
--detect.scan.output.path
```

The output directory for all signature scanner output files\. If not set, the signature scanner output files will be in a 'scan' subdirectory of the output directory\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Source Path
```
--detect.source.path
```

The source path is the path to the project directory to inspect\. If no value is provided, the source path defaults to the current working directory\.

Detect will search the source directory for hints that indicate which package manager\(s\) the project uses, and will attempt to run the corresponding detector\(s\)\. The source path is also the default target for signature scanning\. \(This can be overridden with the detect\.blackduck\.signature\.scanner\.paths property\.\)

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Detect Tools Included
```
--detect.tools=ALL,NONE,DETECTOR,SIGNATURE_SCAN,BINARY_SCAN,IMPACT_ANALYSIS,POLARIS,DOCKER,BAZEL 
```

The tools Detect should allow in a comma\-separated list\. Tools in this list \(as long as they are not also in the excluded list\) will be allowed to run if all criteria of the tool are met\. Exclusion rules always win\.

This property and detect\.tools\.excluded provide control over which tools Detect runs\.

|Details||
|---|---|
|Added|5\.0\.0|
|Type|DetectTool List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|ALL, NONE, DETECTOR, SIGNATURE\_SCAN, BINARY\_SCAN, IMPACT\_ANALYSIS, POLARIS, DOCKER, BAZEL|
|Strict|Yes|
|Example|``|

## Detect Tools Excluded
```
--detect.tools.excluded=ALL,NONE,DETECTOR,SIGNATURE_SCAN,BINARY_SCAN,IMPACT_ANALYSIS,POLARIS,DOCKER,BAZEL 
```

The tools Detect should not allow, in a comma\-separated list\. Excluded tools will not be run even if all criteria for the tool is met\. Exclusion rules always win\.

This property and detect\.tools provide control over which tools Detect runs\.

|Details||
|---|---|
|Added|5\.0\.0|
|Type|DetectTool List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|ALL, NONE, DETECTOR, SIGNATURE\_SCAN, BINARY\_SCAN, IMPACT\_ANALYSIS, POLARIS, DOCKER, BAZEL|
|Strict|Yes|
|Example|``|


## Detector Search Continue (Advanced)
```
--detect.detector.search.continue=false
```

If true, the bom tool search will continue to look for nested bom tools of the same type to the maximum search depth, see the detailed help for more information\.

If true, Detect will find Maven projects that are in subdirectories of a Maven project and Gradle projects that are in subdirectories of Gradle projects, etc\. If false, Detect will only find bom tools in subdirectories of a project if they are of a different type such as an Npm project in a subdirectory of a Gradle project\.

|Details||
|---|---|
|Added|3\.2\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Detect Excluded Directories (Advanced)
```
--detect.excluded.directories
```

A comma\-separated list of names, name patterns, relative paths, or path patterns of directories that Detect should exclude\.

Subdirectories whose name or path is resolved from the patterns in this list will not be searched when determining which detectors to run, and will be excluded from signature scan using the Scan CLI '\-\-exclude' flag\. Refer to the <i>Downloading and Running Synopsys Detect</i> > <i>Including and Excluding Tools, Detectors, Directories, etc\.</i> page for more details\.

|Details||
|---|---|
|Added|7\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|`**/*-test`|

## Detect Excluded Directories Defaults Disabled (Advanced)
```
--detect.excluded.directories.defaults.disabled=false
```

If false, Detect will exclude the default directory names\. See the detailed help for more information\.

If false, the following directories will be excluded by Detect when searching for detectors: bin, build, \.git, \.gradle, node\_modules, out, packages, target, \.synopsys, and the following directories will be excluded from signature scan using the Scan CLI '\-\-exclude' flag: \.git, \.gradle, node\_modules, \.synopsys\.

|Details||
|---|---|
|Added|7\.0\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Detect Tools Output Path (Advanced)
```
--detect.tools.output.path
```

The path to the tools directory where detect should download and/or access things like the Signature Scanner that it shares over multiple runs\.

If set, Detect will use the given directory instead of using the default location of output path plus tools\.

|Details||
|---|---|
|Added|5\.6\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Project Name and Version Detector (Advanced)
```
--detect.project.detector
```

The detector that will be used to determine the project name and version when multiple detector types apply\. This property should be used with detect\.project\.tool\.

If Detect finds that multiple detectors apply, this property can be used to select the detector that will provide the project name and version\. When using this property, you should also set detect\.project\.tool=DETECTOR

|Details||
|---|---|
|Added|4\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Detector Tool Priority (Advanced)
```
--detect.project.tool=DETECTOR,SIGNATURE_SCAN,BINARY_SCAN,IMPACT_ANALYSIS,POLARIS,DOCKER,BAZEL 
```

The tool priority for project name and version\. The project name and version will be determined by the first tool in this list that provides them\.

This allows you to control which tool provides the project name and version when more than one tool are capable of providing it\.

|Details||
|---|---|
|Added|5\.0\.0|
|Type|DetectTool List|
|Default Value|DOCKER,DETECTOR,BAZEL|
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|DETECTOR, SIGNATURE\_SCAN, BINARY\_SCAN, IMPACT\_ANALYSIS, POLARIS, DOCKER, BAZEL|
|Strict|Yes|
|Example|``|



## BDIO 2 Enabled (Deprecated) 
```
--detect.bdio2.enabled=true
```

The version of BDIO files to generate\.

If set to false, BDIO version 1 will be generated\. If set to true, BDIO version 2 will be generated\.

**DEPRECATED: This property is being removed, along with the option to generate BDIO in BDIO1 format\. In the future, BDIO2 format will be the only option\. It will be removed in 8\.0\.0.**

|Details||
|---|---|
|Added|6\.1\.0|
|Type|Boolean|
|Default Value|true|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

